<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      size="small"
      :inline="true"
      v-show="showSearch"
      label-width="68px"
      @submit.native.prevent
    >
      <el-form-item label="码头" prop="harborId">
        <el-select v-model="queryParams.harborId" placeholder="请选择码头">
          <el-option key="0" label="所有" :value="0" />
          <el-option
            v-for="item in whOptions"
            :key="item.pkId"
            :label="item.dockName"
            :value="item.pkId"
          ></el-option>
        </el-select>
      </el-form-item>
      <!-- <el-form-item label="码头id" prop="whId">
        <el-input
          v-model="queryParams.whId"
          placeholder="请输入码头id"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item> -->
      <!-- <el-form-item label="泊位名称" prop="name">
        <el-input
          v-model="queryParams.name"
          placeholder="请输入泊位名称"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item> -->
      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery"
          >搜索</el-button
        >
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['system:berth:add']"
          >新增</el-button
        >
      </el-col>

      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table
      v-loading="loading"
      :data="berthList"
      @selection-change="handleSelectionChange"
    >
      <el-table-column label="序号" align="center" type="index" />
      <el-table-column label="港口名称" align="center" prop="harborName" />
      <el-table-column label="泊位名称" align="center" prop="name" />
      <el-table-column label="泊位长度" align="center" prop="berthLen" />
      <el-table-column label="最小水深" align="center" prop="depth" />
      <el-table-column label="停泊舰艇数量" align="center" prop="shipsNum" />
      <el-table-column prop="status" label="状态" width="60">
        <template slot-scope="scope">
          <span>{{ scope.row.status === 1 ? "启用" : "停用" }}</span>
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:berth:edit']"
            >修改</el-button
          >
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:berth:remove']"
            >删除</el-button
          >
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total > 0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改码头-泊位对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="码头" prop="harborId">
          <el-select v-model="form.harborId" placeholder="请选择码头">
            <el-option
              v-for="item in whOptions"
              :key="item.pkId"
              :label="item.dockName"
              :value="item.pkId"
            ></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="泊位名称" prop="name">
          <el-input v-model="form.name" placeholder="请输入泊位名称" />
        </el-form-item>
        <el-form-item label="泊位长度" prop="berthLen">
          <el-input v-model="form.berthLen" type="number" placeholder="请输入泊位名称" />
        </el-form-item>
        <el-form-item label="最小水深" prop="depth">
          <el-input v-model="form.depth" type="number" placeholder="请输入最小水深" />
        </el-form-item>
        <el-form-item label="停泊舰艇数量" prop="shipsNum">
          <el-input v-model="form.shipsNum" type="number" placeholder="请输入最小水深" />
        </el-form-item>
        <el-form-item label="可用状态" prop="status">
          <el-select v-model="form.status" placeholder="请选择状态">
            <el-option key="99" label="正常" :value="1"></el-option>
            <el-option key="100" label="停用" :value="0"></el-option>
          </el-select>
        </el-form-item>
        <el-form-item label="排序" prop="orderNum">
          <el-input v-model="form.orderNum" type="number" placeholder="请输入序号" />
        </el-form-item>
      </el-form>

      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>
  </div>
</template>

<script>
import { listBerth, getBerth, delBerth, addBerth, updateBerth } from "@/api/manage/berth";
import { listAll } from "@/api/manage/stock";
import { equList } from "@/api/manage/equipment";

export default {
  name: "Berth",
  data() {
    return {
      // 遮罩层
      loading: true,
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 码头-泊位表格数据
      berthList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        whId: null,
        beName: null,
      },
      // 表单参数
      form: {},
      //码头选项
      whOptions: [],
      // 表单校验
      rules: {
        whId: [{ required: true, message: "码头id不能为空", trigger: "blur" }],
        beName: [{ required: true, message: "泊位名称不能为空", trigger: "blur" }],
      },
    };
  },
  created() {
    this.getList();
    listAll().then((response) => {
      console.log(response);
      this.whOptions = response.data;
    });
  },
  methods: {
    /** 查询码头-泊位列表 */
    getList() {
      this.loading = true;
      listBerth(this.queryParams).then((response) => {
        this.berthList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        beId: null,
        whId: null,
        beName: null,
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map((item) => item.beId);
      this.single = selection.length !== 1;
      this.multiple = !selection.length;
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      listAll().then((response) => {
        console.log(response);
        this.whOptions = response.data;
      });
      this.open = true;
      this.title = "添加码头-泊位";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      console.log(row);
      listAll().then((response) => {
        console.log(response);
        this.whOptions = response.data;
      });
      // const beId = row.beId || this.ids;
      getBerth(row.pkid).then((response) => {
        this.form = response.data;
        this.open = true;
        this.title = "修改码头-泊位";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          if (this.form.pkid != null) {
            updateBerth(this.form).then((response) => {
              this.$modal.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addBerth(this.form).then((response) => {
              this.$modal.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      // const beIds = row.beId || this.ids;
      equList(row.pkid).then((response) => {
        if (response.data.length > 0) {
          this.$message.error(row.name + "下有设备，请先删除对应设备");
        } else {
          this.$modal
            .confirm('是否确认删除"' + row.name + '"?')
            .then(function () {
              return delBerth(row.pkid);
            })
            .then(() => {
              this.getList();
              this.$modal.msgSuccess("删除成功");
            })
            .catch(() => {});
        }
      });
    },
    /** 导出按钮操作 */
    handleExport() {
      this.download(
        "system/berth/export",
        {
          ...this.queryParams,
        },
        `berth_${new Date().getTime()}.xlsx`
      );
    },
  },
};
</script>
